'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var devcycleReactSdk = require('@devcycle/devcycle-react-sdk');
require('react');
var AsyncStorage = require('@react-native-async-storage/async-storage');
var jsxRuntime = require('react/jsx-runtime');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var AsyncStorage__default = /*#__PURE__*/_interopDefaultLegacy(AsyncStorage);

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

var ReactNativeStore =
/** @class */
function () {
  function ReactNativeStore() {
    this.store = AsyncStorage__default["default"];
  }

  ReactNativeStore.prototype.save = function (storeKey, data) {
    this.store.setItem(storeKey, JSON.stringify(data));
  };

  ReactNativeStore.prototype.load = function (storeKey) {
    return this.store.getItem(storeKey).then(function (item) {
      return item ? JSON.parse(item) : undefined;
    });
  };

  ReactNativeStore.prototype.remove = function (storeKey) {
    this.store.removeItem(storeKey);
  };

  return ReactNativeStore;
}();

var DVCProvider = function DVCProvider(props) {
  var config = getReactNativeConfig(props.config);
  return /*#__PURE__*/jsxRuntime.jsx(devcycleReactSdk.DVCProvider, {
    config: config,
    children: props.children
  });
};
var getReactNativeConfig = function getReactNativeConfig(config) {
  var _a;

  var rnConfig = __assign(__assign({}, config), {
    options: __assign(__assign({}, config.options), {
      reactNative: true
    })
  });

  if (!((_a = config.options) === null || _a === void 0 ? void 0 : _a.storage)) {
    rnConfig.options.storage = new ReactNativeStore();
  }

  return rnConfig;
};

var withDVCProvider = function withDVCProvider(config) {
  var reactNativeConfig = getReactNativeConfig(config);
  return devcycleReactSdk.withDVCProvider(reactNativeConfig);
};

Object.defineProperty(exports, 'useDVCClient', {
    enumerable: true,
    get: function () { return devcycleReactSdk.useDVCClient; }
});
Object.defineProperty(exports, 'useIsDVCInitialized', {
    enumerable: true,
    get: function () { return devcycleReactSdk.useIsDVCInitialized; }
});
Object.defineProperty(exports, 'useVariable', {
    enumerable: true,
    get: function () { return devcycleReactSdk.useVariable; }
});
Object.defineProperty(exports, 'useVariableValue', {
    enumerable: true,
    get: function () { return devcycleReactSdk.useVariableValue; }
});
exports.DVCProvider = DVCProvider;
exports.withDVCProvider = withDVCProvider;
